Struct InkyBoard

pub struct InkyBoard<'a> { /* private fields */ }

Implementations

Source

impl<'a> InkyBoard<'a>

pub fn get() -> InkyBoard<'a>

pub fn leds(&self) -> &Leds

pub fn spi_bus(&self) -> &Spi

pub fn sync_pcf_to_rtc(&self)

pub fn sync_rtc_to_pcf(&self)

pub fn buttons(&self) -> &mut Buttons

pub fn set_rtc_and_pcf(&self, v: Time)

pub fn wake_reason(&self) -> WakeReason

pub fn i2c_bus(&self) -> &I2cController

pub fn pcf(&'a self) -> &'a mut PcfRtc<'a>

pub fn sd_card(&self) -> Storage<Card<'_>>

pub fn shift_register(&self) -> &ShiftRegister

pub fn set_rtc_wake(&self, secs: u32) -> Result<u32, RtcError>

Returns wait period in milliseconds.

pub unsafe fn power_off(&self)

SAFETY: This is unsafe as this will immediately power off the device if it’s on LIPO/Battery power. Make sure to sync and finish all work beforehand.

This has no affect if powered by USB or External (non-Battery) and cannot be ‘!’.

pub unsafe fn deep_sleep(&self, secs: u32) -> Result<(), RtcError>

SAFETY: This is unsafe as this will immediately power off the device if it’s on LIPO/Battery power. Make sure to sync and finish all work beforehand.

The device will wake up after the specified number of seconds. If powered externally by USB or External (non-Battery), the device will sleep for the period of time instead.

Methods from Deref<Target = Pico>

pub fn sleep(&self, ms: u32)

pub fn timer(&self) -> &Timer

pub fn rtc(&self) -> &RtcClock

pub fn sleep_us(&self, us: u32)

pub fn system_freq(&self) -> u32

pub fn current_tick(&self) -> u64

pub fn watchdog(&self) -> &Watchdog

pub fn system_clock(&self) -> &Clock

pub fn pin(&self, p: PinID) -> Pin<Output>